#*******************************************************************************
#Licensed Materials - Property of IBM
#(c) Copyright IBM Corporation 2008, 2009. All Rights Reserved.
#
#Note to U.S. Government Users Restricted Rights:
#Use, duplication or disclosure restricted by GSA ADP Schedule
#Contract with IBM Corp.
#*******************************************************************************
#!/bin/sh

CURL=/usr/bin/curl
AREA="Quality+Manager"
INTEGRATION_SERVICE=jazz/secure/service/com.ibm.rqm.integration.service.IIntegrationService
COOKIE_JAR="/tmp/curl.cookie.jar.$$.txt"
DIRNAME=.

Usage()
{
    echo
    echo "Usage: $0 [options]"
    echo "    -h          : show this help"
    echo "    -s server   : RQM server. E.g. https://servername:9443/"
    echo "    -u username : login username"
    echo "    -p password : login password"
    echo "    -t type     : type of resource.  E.g. testcase"
    echo "    -f file     : XML file to import"
    echo "    -n id       : id for new artifact (optional)"
    echo "    -i          : allow insecure SSL"
    echo "    -a area     : project area. Default is Quality+Manager"    
    echo
    exit 1
}

ExitRmCookie()
{
    EXIT_CODE=$?
    rm -f $COOKIE_JAR
    exit $EXIT_CODE
}

##############  Get options
while getopts "his:p:u:a:d:t:f:n:" flag; do
    case $flag in
       "s") SERVER=$OPTARG ;;
       "u") USER=$OPTARG ;;
       "p") PASSWORD=$OPTARG ;;
       "a") AREA=$OPTARG ;;       
       "i") CURL="$CURL --insecure" ;;
       "t") TYPE=$OPTARG ;;
       "f") FILE=$OPTARG ;;
       "n") ID=$OPTARG ;;
       "h") Usage ;;
    esac
done

if [ X$SERVER == X ]; then
    Usage
fi

if [ X$TYPE == X ]; then
    Usage
fi

if [ X$FILE == X ]; then
    Usage
fi

if [ ! -f $FILE ]; then
   echo "File not found: $FILE"
   exit 1
fi


if [ X$ID == X ]; then
   ID=$TYPE.`date +%s`.$$
fi


##############  Form login
touch $COOKIE_JAR
chmod og-rwx $COOKIE_JAR
$CURL -# --cookie-jar $COOKIE_JAR ${SERVER}${INTEGRATION_SERVICE} &> /dev/null
if [ $? != 0  ]; then
    ExitRmCookie
fi

$CURL -# --location --cookie $COOKIE_JAR --cookie-jar $COOKIE_JAR --data j_username="$USER" --data j_password="$PASSWORD" ${SERVER}jazz/j_security_check &>/dev/null
if [ $? != 0  ]; then
    ExitRmCookie
fi

##############  PUT the artifact
echo Importing file $FILE to location ${SERVER}${INTEGRATION_SERVICE}/resources/$AREA/$TYPE/$ID
$CURL --request PUT --cookie $COOKIE_JAR  --user $USER:$PASSWORD --upload-file $FILE ${SERVER}${INTEGRATION_SERVICE}/resources/$AREA/$TYPE/$ID

ExitRmCookie
