#!/bin/sh
#*******************************************************************************
#Licensed Materials - Property of IBM
#(c) Copyright IBM Corporation 2009. All Rights Reserved.
#
#Note to U.S. Government Users Restricted Rights:
#Use, duplication or disclosure restricted by GSA ADP Schedule
#Contract with IBM Corp.
#*******************************************************************************
#*******************************************************************************
#  Instructions:
#  To use this script you must have CURL installed on you client system.
#  The CURL local variable should be set to the location of the curl
#  executable if curl is not on your path.
#*******************************************************************************

CURL=curl
INT_SVC="jazz/secure/service/com.ibm.rqm.integration.service.IIntegrationService"
COOKIE_JAR="/tmp/curl.cookie.jar.$$.txt"
SETTINGS_FILE="/tmp/rqm_settings.$$.txt"
LOG_FILE="/tmp/rqm_settings.$$.log"

Usage()
{
    echo
    echo "Usage: $0 [options]"
    echo "    -h          	      : show this help"
    echo "    -s source server        : RQM server. E.g. https://servername:9443/"
    echo "    -u source username      : login username"
    echo "    -p source password      : login password"
    echo "    -a source area  	      : project area.  E.g. Quality+Manager"
    echo "    -d destination server   : RQM server. Default is same as source."
    echo "    -n destination username : login username. Default is same as source."
    echo "    -w destination password : login password. Default is same as source."
    echo "    -r destination area     : project area.  E.g. Quality+Manager"
    echo
    exit 1;
}

ExitRmFiles()
{
    EXIT_CODE=$?
    rm -f $COOKIE_JAR
    rm -f $SETTINGS_FILE
    rm -f $LOG_FILE
    exit $EXIT_CODE
}

ExitKeepFiles()
{
    EXIT_CODE=$?
    exit $EXIT_CODE
}

##############  Get options
while getopts "hs:p:u:a:d:n:w:r:" flag; do
    case $flag in
       "s") S_SERVER=$OPTARG ;;
       "u") S_USER=$OPTARG ;;
       "p") S_PASSWORD=$OPTARG ;;
       "a") S_AREA=$OPTARG ;;
       "d") D_SERVER=$OPTARG ;;
       "n") D_USER=$OPTARG ;;
       "w") D_PASSWORD=$OPTARG ;;
       "r") D_AREA=$OPTARG ;;
       "h") Usage ;;
    esac
done

if [ X$S_SERVER == X ]; then
    Usage
fi
if [ X$S_USER == X ]; then
    Usage
fi
if [ X$S_PASSWORD == X ]; then
    Usage
fi
if [ X$S_AREA == X ]; then
    Usage
fi
if [ X$D_SERVER == X ]; then
    D_SERVER="$S_SERVER"
fi
if [ X$D_USER == X ]; then
    D_USER="$S_USER"
fi
if [ X$D_PASSWORD == X ]; then
    D_PASSWORD="$S_PASSWORD"
fi
if [ X$D_AREA == X ]; then
    Usage
fi


##############  Form login to source server
touch $COOKIE_JAR
chmod og-rwx $COOKIE_JAR

$CURL -k --cookie-jar $COOKIE_JAR ${S_SERVER}${INT_SVC}
if [ $? != 0 ]; then
	echo "connecting to source server failed"
	ExitKeepFiles
fi

$CURL -k --location --cookie $COOKIE_JAR --cookie-jar $COOKIE_JAR --data j_username=${S_USER} --data j_password=${S_PASSWORD} ${S_SERVER}jazz/j_security_check >/${LOG_FILE}
if [ $? != 0 ]; then
	echo "login to source server failed"
	ExitKeepFiles
fi

echo "login to source server succeeded"

##############  GET the settings
echo "Getting project settings"

$CURL -k --cookie $COOKIE_JAR --user ${S_USER}:${S_PASSWORD} "${S_SERVER}${INT_SVC}/project/${S_AREA}/settings" > ${SETTINGS_FILE}

if [ X$S_SERVER != X$D_SERVER ]; then
    ##############  Form login to destination server
    rm -f $COOKIE_JAR
	$CURL -k --cookie-jar $COOKIE_JAR ${D_SERVER}${INT_SVC}
	if [ $? != 0 ]; then
		echo "connect to destination server failed"
		ExitKeepFiles
	fi

	$CURL -k --location --cookie $COOKIE_JAR --cookie-jar $COOKIE_JAR --data j_username=${D_USER} --data j_password=${D_PASSWORD} ${D_SERVER}jazz/j_security_check >${SETTINGS_LOG}
	if [ $? != 0 ]; then
		echo "login to destination server failed"
		ExitKeepFiles
	fi

	echo "login to destination server succeeded"
fi

##############  PUT the settings
echo "Putting project settings"

$CURL -k --request PUT --cookie $COOKIE_JAR --user ${D_USER}:${D_PASSWORD} --upload-file ${SETTINGS_FILE} "${D_SERVER}${INT_SVC}/project/${D_AREA}/settings"

ExitRmFiles
